# API Reference

Complete API documentation for PyRADE.

## Core Classes

```{eval-rst}
.. automodule:: pyrade.core.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pyrade.core.population
   :members:
   :undoc-members:
   :show-inheritance:
```

## Operators

### Mutation Strategies

```{eval-rst}
.. automodule:: pyrade.operators.mutation
   :members:
   :undoc-members:
   :show-inheritance:
```

### Crossover Strategies

```{eval-rst}
.. automodule:: pyrade.operators.crossover
   :members:
   :undoc-members:
   :show-inheritance:
```

### Selection Strategies

```{eval-rst}
.. automodule:: pyrade.operators.selection
   :members:
   :undoc-members:
   :show-inheritance:
```

## Utilities

### Boundary Handlers

```{eval-rst}
.. automodule:: pyrade.utils.boundary
   :members:
   :undoc-members:
   :show-inheritance:
```

### Termination Criteria

```{eval-rst}
.. automodule:: pyrade.utils.termination
   :members:
   :undoc-members:
   :show-inheritance:
```

## Benchmark Functions

```{eval-rst}
.. automodule:: pyrade.benchmarks.functions
   :members:
   :undoc-members:
   :show-inheritance:
```
